@@ -34,8 +34,10 @@ extensions = [
     'sphinx.ext.mathjax',
     'sphinx_automodapi.automodapi',
     'sphinx_automodapi.smart_resolver',
-    "sphinx.ext.autosummary",
-    "matplotlib.sphinxext.plot_directive"
+    'sphinx.ext.autosectionlabel',
+    'sphinx.ext.autosummary',
+    'matplotlib.sphinxext.plot_directive',
+    'numpydoc'
 ]
 
 # Add any paths that contain templates here, relative to this directory.
@@ -58,16 +60,32 @@ master_doc = 'index'
 # Example configuration for intersphinx: refer to the Python standard library.
 intersphinx_mapping = {
     'https://docs.python.org/': None,
-    'specutils': ('https://specutils.readthedocs.io/en/stable/', None)
+    'specutils': ('https://specutils.readthedocs.io/en/stable/', None),
+    'astropy': ('https://docs.astropy.org/en/stable/', None),
 }
 
-# -- Options for HTML output -------------------------------------------------
+html_theme = 'sphinx_book_theme'
 
-# The theme to use for HTML and HTML Help pages.  See the documentation for
-# a list of builtin themes.
-html_theme = 'alabaster'
+html_logo = "assets/logo.png"
+html_favicon = "assets/logo.ico"
 
-# Add any paths that contain custom static files (such as style sheets) here,
-# relative to this directory. They are copied after the builtin static files,
-# so a file named "default.css" will overwrite the builtin "default.css".
-# html_static_path = ['_static']
+html_theme_options = {
+    "use_download_button": True,
+    "repository_url": "https://github.com/bmorris3/expecto",
+    "repository_branch": "main",
+    "path_to_docs": "docs",
+}
+
+numpydoc_show_class_members = False
+autodoc_inherit_docstrings = True
+
+html_context = {
+    "display_github": True,
+    "github_user": "bmorris3",
+    "github_repo": "expecto",
+    "github_version": "main",
+    "conf_py_path": "docs/",
+}
+
+autosectionlabel_prefix_document = True
+autoclass_content = 'both'
